# Pace Layering Framework
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/pace-layering#overview)
  * [Why Is It Relevant?](https://help.sap.com/docs/leanix/ea/pace-layering#why-is-it-relevant?)
  * [How to Implement Pace Layering in SAP LeanIX](https://help.sap.com/docs/leanix/ea/pace-layering#how-to-implement-pace-layering-in-sap-leanix)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/pace-layering#prerequisites)
